==> webkit2gtk_2.20.5.orig.tar.xz: webkitgtk-2.20.5/Source/WebKit/Shared/WebUserContentControllerDataTypes.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/UserScript.h>
#include <WebCore/UserStyleSheet.h>

namespace IPC {
class Decoder;
class Encoder;
}

namespace WebKit {

struct WebUserScriptData {
    void encode(IPC::Encoder&) const;
    static std::optional<WebUserScriptData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    WebCore::UserScript userScript;
};

struct WebUserStyleSheetData {
    void encode(IPC::Encoder&) const;
    static std::optional<WebUserStyleSheetData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    WebCore::UserStyleSheet userStyleSheet;
};

struct WebScriptMessageHandlerData {
    void encode(IPC::Encoder&) const;
    static std::optional<WebScriptMessageHandlerData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    String name;
};

} // namespace WebKit

==> webkit2gtk_2.24.4.orig.tar.xz: webkitgtk-2.24.4/Source/WebKit/Shared/WebUserContentControllerDataTypes.h <==
/*
 * Copyright (C) 2016 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include <WebCore/UserScript.h>
#include <WebCore/UserStyleSheet.h>

namespace IPC {
class Decoder;
class Encoder;
}

namespace WebKit {

struct WebUserScriptData {
    void encode(IPC::Encoder&) const;
    static Optional<WebUserScriptData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    WebCore::UserScript userScript;
};

struct WebUserStyleSheetData {
    void encode(IPC::Encoder&) const;
    static Optional<WebUserStyleSheetData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    WebCore::UserStyleSheet userStyleSheet;
};

struct WebScriptMessageHandlerData {
    void encode(IPC::Encoder&) const;
    static Optional<WebScriptMessageHandlerData> decode(IPC::Decoder&);

    uint64_t identifier;
    uint64_t worldIdentifier;
    String name;
};

} // namespace WebKit
